@@ -1,11 +1,8 @@
-extern crate itertools;
-extern crate pathfinding;
-extern crate rand;
-
 use itertools::Itertools;
 use pathfinding::directed::topological_sort::topological_sort as tsort;
 use pathfinding::directed::topological_sort::topological_sort_into_groups;
 use rand::prelude::SliceRandom;
+use rand::rngs;
 
 #[test]
 fn empty() {
@@ -17,7 +14,7 @@ fn empty() {
 fn order() {
     // Shuffle integers from 1 to 1000, and order them so that divisors
     // are located before the numbers they divide.
-    let mut rng = rand::rngs::OsRng::new().unwrap();
+    let mut rng = rngs::OsRng::new().unwrap();
     let mut ints = (1..1000).collect_vec();
     ints.shuffle(&mut rng);
     let sorted = tsort(&ints, |&n| {
@@ -40,7 +37,7 @@ fn order() {
 fn complexity() {
     // To ensure that the sort is O(|E| + |V|), we ensure that the
     // successors for a particular node are requested exactly one time.
-    let mut rng = rand::rngs::OsRng::new().unwrap();
+    let mut rng = rngs::OsRng::new().unwrap();
     let mut ints = (1..1000).collect_vec();
     ints.shuffle(&mut rng);
     let mut requested = 0;
@@ -59,12 +56,9 @@ fn complexity() {
 // Wrapper around topological_sort_into_groups that sorts each group (since
 // topological_sort_into_groups makes no guarantees about node order within
 // each group).
-fn tsig(succs: &[&[usize]])
-        -> Result<Vec<Vec<usize>>, (Vec<Vec<usize>>, Vec<usize>)> {
+fn tsig(succs: &[&[usize]]) -> Result<Vec<Vec<usize>>, (Vec<Vec<usize>>, Vec<usize>)> {
     let nodes: Vec<usize> = (0..succs.len()).into_iter().collect();
-    match topological_sort_into_groups(&nodes, |&n| {
-        succs[n].iter().cloned()
-    }) {
+    match topological_sort_into_groups(&nodes, |&n| succs[n].iter().cloned()) {
         Ok(mut groups) => {
             for group in groups.iter_mut() {
                 group.sort();
@@ -93,15 +87,19 @@ fn tsig_graph_with_no_edges() {
 
 #[test]
 fn tsig_diamond() {
-    assert_eq!(tsig(&[&[1, 2], &[3], &[3], &[]]),
-               Ok(vec![vec![0], vec![1, 2], vec![3]]));
+    assert_eq!(
+        tsig(&[&[1, 2], &[3], &[3], &[]]),
+        Ok(vec![vec![0], vec![1, 2], vec![3]])
+    );
 }
 
 #[test]
 fn tsig_multiple_layers() {
     let succs: &[&[usize]] = &[&[1, 5], &[2], &[3], &[], &[5], &[3]];
-    assert_eq!(tsig(succs),
-               Ok(vec![vec![0, 4], vec![1, 5], vec![2], vec![3]]));
+    assert_eq!(
+        tsig(succs),
+        Ok(vec![vec![0, 4], vec![1, 5], vec![2], vec![3]])
+    );
 }
 
 #[test]
@@ -111,12 +109,16 @@ fn tsig_nothing_but_a_cycle() {
 
 #[test]
 fn tsig_chain_then_cycle() {
-    assert_eq!(tsig(&[&[1], &[2], &[3], &[2, 4], &[]]),
-               Err((vec![vec![0], vec![1]], vec![2, 3, 4])));
+    assert_eq!(
+        tsig(&[&[1], &[2], &[3], &[2, 4], &[]]),
+        Err((vec![vec![0], vec![1]], vec![2, 3, 4]))
+    );
 }
 
 #[test]
 fn tsig_self_edge() {
-    assert_eq!(tsig(&[&[1, 2], &[3], &[3], &[3]]),
-               Err((vec![vec![0], vec![1, 2]], vec![3])));
+    assert_eq!(
+        tsig(&[&[1, 2], &[3], &[3], &[3]]),
+        Err((vec![vec![0], vec![1, 2]], vec![3]))
+    );
 }
